@@ -7,7 +7,7 @@ from typing import List, Optional, Tuple, Union
 from .factory import DrbFactory
 from .item_class import ItemClass, ItemClassType, ItemClassLoader
 from ..node import DrbNode
-from ..exceptions import DrbFactoryException
+from ..exceptions import DrbFactoryException, DrbException
 from ..utils.url_node import UrlNode
 
 
@@ -61,12 +61,8 @@ class DrbFactoryResolver(DrbFactory):
         return cls.__instance
 
     def _create(self, node: DrbNode) -> DrbNode:
-        item_class, base_node = self.resolve(node)
-        if item_class.factory is None:
-            return base_node
-        if base_node is None:
-            return item_class.factory.create(node)
-        return item_class.factory.create(base_node)
+        item_class, n = self.resolve(node)
+        return n
 
     def __retrieve_protocol(self, node: DrbNode) -> Optional[ItemClass]:
         """
@@ -83,22 +79,23 @@ class DrbFactoryResolver(DrbFactory):
                 return protocol
         return None
 
-    def __retrieve_container(self, node: DrbNode) -> Optional[ItemClass]:
+    def __retrieve_container(self, node: DrbNode) -> Tuple[ItemClass, DrbNode]:
         """
         Retrieves the container signature associated to the given node.
 
         Parameters:
             node (DrbNode): node which need to be resolved
         Returns:
-            ItemClass: A item class matching the given node, otherwise ``None``
+            ItemClass, DrbNode: A item class matching the given node and the
+                                associated node
         """
         for s in self.__highest_containers:
             if s.matches(node):
                 return self.__finest_item_class(node, s)
-        return None
+        return None, node
 
     def __finest_item_class(self, node: DrbNode, finest: ItemClass) \
-            -> ItemClass:
+            -> Tuple[ItemClass, DrbNode]:
         """
         Retrieves the finest item class associated to the given node.
 
@@ -113,8 +110,11 @@ class DrbFactoryResolver(DrbFactory):
                       if x.parent_class_id == finest.id]
         for item_class in subclasses:
             if item_class.matches(node):
-                return self.__finest_item_class(node, item_class)
-        return finest
+                n = node
+                if item_class.factory is not None:
+                    n = item_class.factory.create(node)
+                return self.__finest_item_class(n, item_class)
+        return finest, node
 
     def __retrieve_formatting(self, node) -> Optional[ItemClass]:
         """
@@ -164,7 +164,8 @@ class DrbFactoryResolver(DrbFactory):
                 if child != '':
                     node = node[child]
             return node
-        except (DrbFactoryException, IndexError, KeyError, TypeError):
+        except (DrbFactoryException, DrbException,
+                IndexError, KeyError, TypeError):
             if curl == url or len(path) == 0:
                 raise DrbFactoryException(f'Cannot resolve URL: {url}')
             if is_remote_url(pp):
@@ -181,7 +182,7 @@ class DrbFactoryResolver(DrbFactory):
             Optional[Tuple[ItemClass, Optional[DrbNode]]]:
         for ic in self.__overridden:
             if ic.matches(source):
-                return self.__finest_item_class(source, ic), source
+                return self.__finest_item_class(source, ic)
         return None
 
     def _basic_resolve(self, source: DrbNode) -> \
@@ -198,24 +199,21 @@ class DrbFactoryResolver(DrbFactory):
                 raise DrbFactoryException(f'Cannot resolve: {source}')
             node = protocol.factory.create(node)
 
-        container = self.__retrieve_container(node)
-        old_node = None
-        if container is not None:
-            if container.factory is not None:
-                old_node = node
-                node = container.factory.create(node)
+        container, node = self.__retrieve_container(node)
+        if container is not None and container.factory is not None:
+            node = container.factory.create(node)
 
         formatting = self.__retrieve_formatting(node)
         if formatting is not None:
-            return self.__finest_item_class(node, formatting), node
+            if formatting.factory is not None:
+                node = formatting.factory.create(node)
+            return self.__finest_item_class(node, formatting)
 
         if container is None:
             if protocol is None:
                 raise DrbFactoryException(f'Cannot resolve: {source}')
-            return protocol, None
+            return protocol, node
 
-        if old_node is not None:
-            return container, old_node
         return container, node
 
     def resolve(self, source: Union[str, DrbNode]) \
