@@ -188,7 +188,7 @@ class ChildSignature(Signature):
 
     def matches(self, node: DrbNode) -> bool:
         try:
-            n = node / self.__predicate
+            n = node[self.__predicate]
             return len(n) > 0
         except DrbException:
             return False
