@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 import abc
-from typing import List, Dict, Optional, Tuple, Any
+from typing import List, Dict, Optional, Tuple, Any, Callable
 from .item import DrbItem
 from .node_impl import NodeImpl
 from .path import ParsedPath
+from .events import EventManager
 
 
 class DrbNode(DrbItem, NodeImpl, abc.ABC):
@@ -18,6 +19,7 @@ class DrbNode(DrbItem, NodeImpl, abc.ABC):
 
     def __init__(self):
         self.__namespace_aware = None
+        self.__events = EventManager()
 
     @property
     @abc.abstractmethod
@@ -195,7 +197,7 @@ class DrbNode(DrbItem, NodeImpl, abc.ABC):
 
         * ``True``: take into account children namespace during browsing
         * ``False``: does not take into account children namespace during
-                     browsing
+          browsing
 
         Returns:
             bool: ``True`` if node take care of namespace during browsing of
@@ -220,3 +222,44 @@ class DrbNode(DrbItem, NodeImpl, abc.ABC):
         if value is not None and not isinstance(value, bool):
             raise ValueError('Only a value boolean is expected here !')
         self.__namespace_aware = value
+
+    @property
+    def _event_manager(self) -> EventManager:
+        """
+        Retrieves the EventManager associated to this node.
+
+        Returns:
+             EventManager: the event manager attached to this node
+
+        """
+        return self.__events
+
+    def register(self, event_type: str, callback: Callable):
+        """
+        Registers a new callback on a specific event type.
+
+        Parameters:
+            event_type (str): target event type
+            callback (Callable): the callback to register
+        """
+        self.__events.register(event_type, callback)
+
+    def unregister(self, event_type: str, callback: Callable):
+        """
+        Unregisters a new callback on a specific event type.
+
+        Parameters:
+            event_type (str): target event type
+            callback (Callable): the callback to unregister
+        """
+        self.__events.unregister(event_type, callback)
+
+    def __hash__(self):
+        return hash(self.path.name)
+
+    def __contains__(self, item) -> bool:
+        if isinstance(item, str):
+            return self.has_child(item)
+        if isinstance(item, tuple) and len(item) == 2:
+            return self.has_child(*item)
+        return False
