@@ -1,9 +1,8 @@
-import sys
-import argparse
 import keyring
 import logging
-from keyring.errors import NoKeyringError, KeyringError
+from keyring.errors import KeyringError
 from keyrings.cryptfile.cryptfile import CryptFileKeyring
+from keyrings.cryptfile.file import PlaintextKeyring
 from requests.auth import AuthBase, HTTPBasicAuth
 
 """
@@ -50,8 +49,11 @@ where key_name is a fixed string (i.e. 'username', 'password' ...)
 This change resolved the limitation of storing OAuth2.0 settings, because the
 key/value information stored for one service is not limited.
 A dedicated mechanism shall be defined to manage multiple credentials
-per service. But this use case is currently not handeled by the rest of the
+per service. But this use case is currently not handled by the rest of the
 system.
+
+The bad border effect is the external tools are not any more able to
+add/remove new service credential for this library.
 """
 logger = logging.getLogger('drb-keyring')
 init = False
@@ -89,9 +91,10 @@ def _init_keyring_backed() -> None:
         _log_kr_info(_verbose)
         return
     try:
-        keyring.get_keyring()
-        raise NoKeyringError()
-    except NoKeyringError:
+        key = keyring.get_keyring()
+        if not isinstance(key, PlaintextKeyring):
+            key.keyring_key
+    except Exception:
         kr = CryptFileKeyring()
         kr.keyring_key = 'a25Za/.?$'  # Warn: Same as PlaintextKeyring
         keyring.set_keyring(kr)
@@ -310,70 +313,3 @@ def kr_get_auth(service: str, username: str = None) -> AuthBase:
 
     # This implementation only manage basic auth.
     raise NotImplementedError("Authentication not implemented.")
-
-
-def _add(args):
-    try:
-        kr_add(args.service, args.username, args.password)
-        return 0
-    except Exception:
-        return 1
-
-
-def _remove(args):
-    try:
-        kr_remove(args.service)
-        return 0
-    except Exception:
-        return 1
-
-
-def _check(args):
-    return kr_check(args.service, args.username)
-
-
-def main(argv) -> int:
-    '''
-    keyring_connection:main run keyring main features:
-     - add: adds credential passed in argument in keyring
-     - remove: removes creential for a given service and optional username
-     - check: checks if credential is present in keyring
-    Command line returns 0 exit status when no error happened, 1 otherwise.
-    '''
-    global _verbose
-    parser = argparse.ArgumentParser(description='Manage keyring commands.')
-
-    parser.add_argument("-v", "--verbose", help="increase output verbosity",
-                        action="store_true")
-    groups = parser.add_subparsers(help='commands')
-    add_group = groups.add_parser('add', help="Add new keyring entry")
-    add_group.add_argument('--service', metavar='SERVICE', type=str,
-                           help='Service name')
-    add_group.add_argument('--username', metavar='USERNAME', type=str,
-                           help='Service connection username')
-    add_group.add_argument('--password', metavar='PASSWORD', type=str,
-                           help='Service connection password')
-    add_group.set_defaults(func=_add)
-
-    remove_group = groups.add_parser('del', help="Remove keyring entry")
-    remove_group.add_argument('del', action='store_true')
-    remove_group.add_argument('--service', metavar='SERVICE', type=str,
-                              help='Service name')
-    remove_group.add_argument('--username', metavar='USERNAME', type=str,
-                              help='Service connection username')
-    remove_group.set_defaults(func=_remove)
-
-    check_group = groups.add_parser('check', help="check keyring status")
-    check_group.add_argument('check', action='store_true')
-    check_group.add_argument('--service', metavar='SERVICE', type=str,
-                             help='Service name')
-    check_group.add_argument('--username', metavar='USERNAME', type=str,
-                             help='Service connection username')
-    check_group.set_defaults(func=_check)
-    args = parser.parse_args(argv)
-    set_verbose(args.verbose)
-    return args.func(args)
-
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv[1:]))
